@@ -599,8 +599,10 @@ struct padthv1_key
 
 // glide (portamento)
 
-struct padthv1_glide
+class padthv1_glide
 {
+public:
+
 	padthv1_glide(float& last) : m_last(last) { reset(); }
 
 	void reset( uint32_t frames = 0, float freq = 0.0f )
@@ -810,8 +812,8 @@ class padthv1_midi_in : public padthv1_sched
 {
 public:
 
-	padthv1_midi_in (padthv1 *pSampl)
-		: padthv1_sched(pSampl, MidiIn),
+	padthv1_midi_in (padthv1 *pPadth)
+		: padthv1_sched(pPadth, MidiIn),
 			m_enabled(false), m_count(0) {}
 
 	void schedule_event()
@@ -860,7 +862,7 @@ class padthv1_impl
 {
 public:
 
-	padthv1_impl(padthv1 *pSampl, uint16_t nchannels, float srate, uint32_t nsize);
+	padthv1_impl(padthv1 *pPadth, uint16_t nchannels, float srate, uint32_t nsize);
 
 	~padthv1_impl();
 
@@ -915,7 +917,7 @@ public:
 			m_gen1.freq1 = padthv1_freq(m_gen1.sample1_0);
 		}
 
-		gen1_sample1.reset_test(m_gen1.freq1,
+		gen1_sample1.prev()->reset_test(m_gen1.freq1,
 			*m_gen1.width1, *m_gen1.scale1, uint16_t(*m_gen1.nh1),
 			padthv1_sample::Apodizer(*m_gen1.apod1));
 
@@ -924,11 +926,25 @@ public:
 			m_gen1.freq2 = padthv1_freq(m_gen1.sample2_0);
 		}
 
-		gen1_sample2.reset_test(m_gen1.freq2,
+		gen1_sample2.prev()->reset_test(m_gen1.freq2,
 			*m_gen1.width2, *m_gen1.scale2, uint16_t(*m_gen1.nh2),
 			padthv1_sample::Apodizer(*m_gen1.apod2));
 	}
 
+	void reset_sync(
+		float freq0, float width, float scale,
+		uint16_t nh, int apod, int sid)
+	{
+		padthv1_sample_ref& ref = (sid == 1 ? gen1_sample1 : gen1_sample2);
+		padthv1_sample *prev = ref.prev();
+		padthv1_sample *next = new padthv1_sample(*prev);
+		next->reset_sync(freq0, width, scale, nh,
+			padthv1_sample::Apodizer(apod));
+		ref.append(next);
+		ref.free_refs();
+		ref.clear_refs();
+	}
+
 	void midiInEnabled(bool on);
 	uint32_t midiInCount();
 
@@ -936,7 +952,7 @@ public:
 
 	bool running(bool on);
 
-	padthv1_sample gen1_sample1, gen1_sample2;
+	padthv1_sample_ref gen1_sample1, gen1_sample2;
 
 	padthv1_wave_lf lfo1_wave;
 
@@ -962,6 +978,10 @@ protected:
 		padthv1_voice *pv = m_free_list.next();
 		if (pv) {
 			m_free_list.remove(pv);
+			gen1_sample1.acquire();
+			gen1_sample2.acquire();
+			pv->gen1_osc1.reset(gen1_sample1.next());
+			pv->gen1_osc2.reset(gen1_sample2.next());
 			m_play_list.append(pv);
 			++m_nvoices;
 		}
@@ -970,6 +990,9 @@ protected:
 
 	void free_voice ( padthv1_voice *pv )
 	{
+		gen1_sample1.release();
+		gen1_sample2.release();
+
 		if (m_lfo1.psync == pv)
 			m_lfo1.psync = nullptr;
 
@@ -1053,8 +1076,8 @@ padthv1_voice::padthv1_voice ( padthv1_impl *pImpl ) :
 	note(-1),
 	vel(0.0f),
 	pre(0.0f),
-	gen1_osc1(&pImpl->gen1_sample1),
-	gen1_osc2(&pImpl->gen1_sample2),
+	gen1_osc1(nullptr),
+	gen1_osc2(nullptr),
 	gen1_freq1(0.0f), gen1_sample1(0.0f),
 	gen1_freq2(0.0f), gen1_sample2(0.0f),
 	lfo1(&pImpl->lfo1_wave),
@@ -1073,11 +1096,14 @@ padthv1_voice::padthv1_voice ( padthv1_impl *pImpl ) :
 // engine constructor
 
 padthv1_impl::padthv1_impl (
-	padthv1 *pSampl, uint16_t nchannels, float srate, uint32_t nsize )
-	: gen1_sample1(pSampl, 1), gen1_sample2(pSampl, 2),
-		m_controls(pSampl), m_programs(pSampl),
-		m_midi_in(pSampl), m_bpm(180.0f), m_nvoices(0), m_running(false)
+	padthv1 *pPadth, uint16_t nchannels, float srate, uint32_t nsize )
+	: m_controls(pPadth), m_programs(pPadth),
+		m_midi_in(pPadth), m_bpm(180.0f), m_nvoices(0), m_running(false)
 {
+	// initialize sample lists.
+	gen1_sample1.append(new padthv1_sample(pPadth, 1));
+	gen1_sample2.append(new padthv1_sample(pPadth, 2));
+
 	// null sample freqs.
 	m_gen1.sample1_0 = m_gen1.sample2_0 = 0.0f;
 	m_gen1.freq1 = m_gen1.freq2 = 0.0f;
@@ -1155,6 +1181,11 @@ padthv1_impl::~padthv1_impl (void)
 
 	delete [] m_voices;
 
+	gen1_sample1.clear_refs(true);
+	gen1_sample2.clear_refs(true);
+
+	padthv1_sample::sched_cleanup();
+
 	// deallocate local buffers
 	alloc_sfxs(0);
 
@@ -1205,8 +1236,8 @@ void padthv1_impl::setSampleRate ( float srate )
 	m_srate = srate;
 
 	// update waves sample rate
-	gen1_sample1.setSampleRate(m_srate);
-	gen1_sample2.setSampleRate(m_srate);
+	gen1_sample1.next()->setSampleRate(m_srate);
+	gen1_sample2.next()->setSampleRate(m_srate);
 	lfo1_wave.setSampleRate(m_srate);
 
 	updateEnvTimes();
@@ -1274,9 +1305,9 @@ void padthv1_impl::updateEnvTimes (void)
 
 	float envtime_msecs = 10000.0f * m_gen1.envtime0;
 	if (envtime_msecs < MIN_ENV_MSECS)
-		envtime_msecs = (gen1_sample1.size() >> 1) / srate_ms;
+		envtime_msecs = (gen1_sample1.next()->size() >> 1) / srate_ms;
 	if (envtime_msecs < MIN_ENV_MSECS)
-		envtime_msecs = (gen1_sample2.size() >> 1) / srate_ms;
+		envtime_msecs = (gen1_sample2.next()->size() >> 1) / srate_ms;
 	if (envtime_msecs < MIN_ENV_MSECS)
 		envtime_msecs = MIN_ENV_MSECS * 4.0f;
 
@@ -2321,10 +2352,10 @@ float padthv1::sampleRate (void) const
 padthv1_sample *padthv1::sample ( int sid ) const
 {
 	if (sid == 1)
-		return &(m_pImpl->gen1_sample1);
+		return m_pImpl->gen1_sample1.prev();
 	else
 	if (sid == 2)
-		return &(m_pImpl->gen1_sample2);
+		return m_pImpl->gen1_sample2.prev();
 	else
 		return nullptr;
 }
@@ -2435,6 +2466,13 @@ void padthv1::reset_test (void)
 }
 
 
+void padthv1::reset_sync (
+	float freq0, float width, float scale, uint16_t nh, int apod, int sid )
+{
+	m_pImpl->reset_sync(freq0, width, scale, nh, apod, sid);
+}
+
+
 // all reset clear
 
 void padthv1::reset (void)
