@@ -1,7 +1,7 @@
 // padthv1widget_controls.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -41,7 +41,7 @@ class padthv1widget_controls : public QTreeWidget
 public:
 
 	// ctor.
-	padthv1widget_controls(QWidget *pParent = 0);
+	padthv1widget_controls(QWidget *pParent = nullptr);
 	// dtor.
 	~padthv1widget_controls();
 
