@@ -1,7 +1,7 @@
 // padthv1widget_programs.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ class padthv1widget_programs::ItemDelegate : public QItemDelegate
 public:
 
 	// ctor.
-	ItemDelegate(QObject *pParent = 0);
+	ItemDelegate(QObject *pParent = nullptr);
 
 	// QItemDelegate interface...
 	QSize sizeHint(
@@ -99,7 +99,7 @@ QWidget *padthv1widget_programs::ItemDelegate::createEditor ( QWidget *pParent,
 	{
 		if (index.parent().isValid()) {
 			QComboBox *pComboBox = new QComboBox(pParent);
-			pComboBox->setEditable(true);
+			pComboBox->setEditable(false);
 			padthv1_config *pConfig = padthv1_config::getInstance();
 			if (pConfig)
 				pComboBox->addItems(pConfig->presetList());
@@ -151,7 +151,11 @@ void padthv1widget_programs::ItemDelegate::setEditorData (
 		//	= index.model()->data(index, Qt::DisplayRole).toString();
 		if (index.parent().isValid()) {
 			QComboBox *pComboBox = qobject_cast<QComboBox *> (pEditor);
-			if (pComboBox) pComboBox->setEditText(sText);
+			if (pComboBox) {
+				const int iIndex = pComboBox->findText(sText);
+				if (iIndex >= 0)
+					pComboBox->setCurrentIndex(iIndex);
+			}
 		} else {
 			QLineEdit *pLineEdit = qobject_cast<QLineEdit *> (pEditor);
 			if (pLineEdit) pLineEdit->setText(sText);
@@ -325,19 +329,18 @@ void padthv1widget_programs::savePrograms ( padthv1_programs *pPrograms )
 }
 
 
-void padthv1widget_programs::selectProgram ( padthv1_programs *pPrograms )
+QString padthv1widget_programs::currentProgramName (void) const
 {
+	QString sProgramName;
+
 	const QList<QTreeWidgetItem *>& selectedItems
 		= QTreeWidget::selectedItems();
 	if (!selectedItems.isEmpty()) {
 		QTreeWidgetItem *pProgItem = selectedItems.first();
-		QTreeWidgetItem *pBankItem = pProgItem->parent();
-		if (pBankItem) {
-			const uint16_t bank_id = pBankItem->data(0, Qt::UserRole).toInt();
-			const uint16_t prog_id = pProgItem->data(0, Qt::UserRole).toInt();
-			pPrograms->select_program(bank_id, prog_id);
-		}
+		sProgramName = pProgItem->text(1).simplified();
 	}
+
+	return sProgramName;
 }
 
 
@@ -442,9 +445,17 @@ QTreeWidgetItem *padthv1widget_programs::newProgramItem (void)
 			return nullptr;
 	}
 
+	QString sProgram = tr("Program %1.%2").arg(iBankData).arg(iProgData);
+	padthv1_config *pConfig = padthv1_config::getInstance();
+	if (pConfig) {
+		const QStringList& presets
+			= pConfig->presetList();
+		if (iProgData < presets.count())
+			sProgram = presets.at(iProgData);
+	}
+
 	pProgItem = new QTreeWidgetItem(QStringList()
-		<< QString::number(iProgData) + " ="
-		<< tr("Program %1.%2").arg(iBankData).arg(iProgData));
+		<< QString::number(iProgData) + " =" << sProgram);
 	pProgItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsEditable | Qt::ItemIsSelectable);
 	pProgItem->setData(0, Qt::TextAlignmentRole, int(Qt::AlignRight | Qt::AlignVCenter));
 	pProgItem->setData(0, Qt::UserRole, iProgData);
